@@ -7,6 +7,6 @@ def invoker(arity, f):
     called directly supplied with arguments and a target object.
     The returned function is curried and accepts arity + 1 parameters where
     the final parameter is the target object"""
-    _args = ", ".join([f"x{i}" for i in range(0, arity)])
-    _f = f'lambda {_args}, object: getattr(object, "{f}")({_args})'
+    _args = "".join([f"x{i}, " for i in range(0, arity)])
+    _f = f'lambda {_args} object: getattr(object, "{f}")({_args})'
     return curry(eval(_f))
