@@ -2,7 +2,7 @@ from toolz import curry
 
 
 @curry
-def lte(y, x):
+def lte(x, y):
     """Returns true if the first argument is less than or equal to the second;
     false otherwise"""
     return x <= y
