@@ -7,7 +7,7 @@ def map_obj_indexed(f, xs):
     """An Object-specific version of map. The function is applied to three
     arguments: (value, key, obj). If only the value is significant, use
     map instead"""
-    if isinstance(xs, collections.Mapping):
+    if isinstance(xs, getattr(collections, "abc", collections).Mapping):
         obj = xs.items()
     else:
         obj = enumerate(xs)
